import { r as requireObjectCoercible, f as fails, _ as _export } from './export-54398709.js';
import '@babel/runtime/helpers/esm/defineProperty';
import { _ as _objectSpread2, c as classAppend, a as classRemove, v as variant, C as Classy, r as registerComponent } from './index-fad2593b.js';
import { defineComponent, computed, inject, openBlock, createBlock, createVNode, renderSlot, createCommentVNode } from 'vue';
import 'clsx';
import 'twind';
import merge from 'lodash.merge';
import 'core-js/modules/es.string.anchor.js';

var quot = /"/g;

// B.2.3.2.1 CreateHTML(string, tag, attribute, value)
// https://tc39.es/ecma262/#sec-createhtml
var createHtml = function (string, tag, attribute, value) {
  var S = String(requireObjectCoercible(string));
  var p1 = '<' + tag;
  if (attribute !== '') p1 += ' ' + attribute + '="' + String(value).replace(quot, '&quot;') + '"';
  return p1 + '>' + S + '</' + tag + '>';
};

// check the existence of a method, lowercase
// of a tag and escaping quotes in arguments
var stringHtmlForced = function (METHOD_NAME) {
  return fails(function () {
    var test = ''[METHOD_NAME]('"');
    return test !== test.toLowerCase() || test.split('"').length > 3;
  });
};

// `String.prototype.anchor` method
// https://tc39.es/ecma262/#sec-string.prototype.anchor
_export({ target: 'String', proto: true, forced: stringHtmlForced('anchor') }, {
  anchor: function anchor(name) {
    return createHtml(this, 'a', 'name', name);
  }
});

const anchorBase = 'inline-flex space-x-2 focus:ring-2 rounded-sm ring-opacity-50 outline-none';
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types, @typescript-eslint/no-explicit-any
const Theme = (userTheme) => {
    return merge({
        BASE: anchorBase,
        primary: `${anchorBase} text-green-500 hover:text-green-800 focus:text-green-800 dark:hover:text-green-300 dark:focus:text-green-300 ring-green-500`,
        secondary: `${anchorBase} text-blue-500 dark:text-blue-400 hover:text-blue-700 dark:hover:text-blue-300 focus:text-blue-800 dark:focus:text-blue-300 ring-blue-500`,
    }, userTheme ? userTheme.Anchor : null);
};

var script = defineComponent({
  name: "Anchor",
  props: _objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({}, classAppend({
    type: [String, Object]
  })), classRemove({
    type: [String, Object]
  })), variant({
    default: "BASE"
  })), {}, {
    href: {
      type: String,
      required: true
    },
    newTab: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup(props) {
    var _computed = computed(function () {
      return Theme(inject("userTheme", {}));
    }),
        theme = _computed.value;

    var variantIsStr = typeof props.variant === "string";
    var classAppendIsStr = typeof props.classAppend === "string";
    var classRemoveIsStr = typeof props.classRemove === "string";
    var classes = computed(function () {
      var _props$classAppend$ic, _props$classRemove$ic;

      return {
        anchor: new Classy().append(theme[variantIsStr ? props.variant : props.variant.anchor]).append(classAppendIsStr ? props.classAppend : props.classAppend.anchor).remove(classRemoveIsStr ? props.classRemove : props.classRemove.anchor).twind().val(),
        icon: new Classy() // .append(props.variant.icon ? theme[props.variant.icon] : "")
        .append((_props$classAppend$ic = props.classAppend.icon) !== null && _props$classAppend$ic !== void 0 ? _props$classAppend$ic : "w-4").remove((_props$classRemove$ic = props.classRemove.icon) !== null && _props$classRemove$ic !== void 0 ? _props$classRemove$ic : "").twind().val()
      };
    });
    return {
      classes: classes
    };
  }
});

var _hoisted_1 = /*#__PURE__*/createVNode("path", {
  d: "M11 3a1 1 0 100 2h2.586l-6.293 6.293a1 1 0 101.414 1.414L15 6.414V9a1 1 0 102 0V4a1 1 0 00-1-1h-5z"
}, null, -1);

var _hoisted_2 = /*#__PURE__*/createVNode("path", {
  d: "M5 5a2 2 0 00-2 2v8a2 2 0 002 2h8a2 2 0 002-2v-3a1 1 0 10-2 0v3H5V7h3a1 1 0 000-2H5z"
}, null, -1);

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createBlock("a", {
    class: _ctx.classes.anchor,
    href: _ctx.href,
    rel: _ctx.newTab ? 'noopener noreferrer' : null,
    target: _ctx.newTab ? '_blank' : null
  }, [createVNode("div", null, [renderSlot(_ctx.$slots, "default")]), _ctx.newTab ? (openBlock(), createBlock("svg", {
    key: 0,
    class: _ctx.classes.icon,
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 20 20",
    fill: "currentColor"
  }, [_hoisted_1, _hoisted_2], 2)) : createCommentVNode("", true)], 10, ["href", "rel", "target"]);
}

script.render = render;

const AnchorPlugin = {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    install: (vue) => {
        registerComponent(vue, script);
    }
};

export default script;
export { AnchorPlugin };
